=============
Example Usage
=============

.. treemap:: default
    :input: input/coverage_data.xml

.. treemap:: custom pink
    :limits: 90 80 70 0
    :colors: lightgreen orange yellow darkred
    :input: <<outdir>>/input/coverage_data.xml

